@@ -1,4 +1,4 @@
-//@line 37 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/aboutDialog.js"
+//@line 37 "/builds/moz2_slave/linux_build/build/browser/base/content/aboutDialog.js"
 
 var gSelectedPage = 0;
 
@@ -38,8 +38,13 @@ function init(aEvent)
   button.setAttribute("accesskey", document.documentElement.getAttribute("creditsaccesskey"));
   button.addEventListener("command", switchPage, false);
 
-  document.documentElement.getButton("accept").focus();
-//@line 82 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/aboutDialog.js"
+  var acceptButton = document.documentElement.getButton("accept");
+//@line 78 "/builds/moz2_slave/linux_build/build/browser/base/content/aboutDialog.js"
+  acceptButton.setAttribute("icon", "close");
+//@line 80 "/builds/moz2_slave/linux_build/build/browser/base/content/aboutDialog.js"
+  acceptButton.focus();
+
+//@line 87 "/builds/moz2_slave/linux_build/build/browser/base/content/aboutDialog.js"
 }
 
 function uninit(aEvent)
