@@ -1,18 +1,18 @@
 /*
-//@line 44 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 44 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
  */
 
 //****************************************************************************//
 // Constants & Enumeration Values
 
 /*
-//@line 51 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 51 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
 */
 var Cc = Components.classes;
 var Ci = Components.interfaces;
 var Cr = Components.results;
 /*
-//@line 57 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 57 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
 */
 
 const TYPE_MAYBE_FEED = "application/vnd.mozilla.maybe.feed";
@@ -70,7 +70,13 @@ const PREF_AUDIO_FEED_SELECTED_READER = "browser.audioFeeds.handler.default";
 // identifying the "use plugin" action, so we use this constant instead.
 const kActionUsePlugin = 5;
 
-const ICON_URL_APP      = "chrome://browser/skin/preferences/application.png";
+/*
+//@line 116 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
+*/
+const ICON_URL_APP      = "moz-icon://dummy.exe?size=16";
+/*
+//@line 124 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
+*/
 
 // For CSS. Can be one of "ask", "save", "plugin" or "feed". If absent, the icon URL
 // was set by us to a custom handler icon and CSS should not try to override it.
@@ -81,7 +87,7 @@ const APP_ICON_ATTR_NAME = "appHandlerIcon";
 
 function getDisplayNameForFile(aFile) {
 /*
-//@line 149 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 159 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
 */
 
   return Cc["@mozilla.org/network/io-service;1"].
@@ -473,9 +479,9 @@ FeedHandlerInfo.prototype = {
     getService(Ci.nsIWebContentConverterService),
 
   _shellSvc:
-//@line 541 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 551 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
     getShellService(),
-//@line 545 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 555 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
 
 
   //**************************************************************************//
@@ -598,14 +604,14 @@ FeedHandlerInfo.prototype = {
       return this.__defaultApplicationHandler;
 
     var defaultFeedReader = null;
-//@line 668 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 678 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
     try {
       defaultFeedReader = this._shellSvc.defaultFeedReader;
     }
     catch(ex) {
       // no default reader or _shellSvc is null
     }
-//@line 675 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 685 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
 
     if (defaultFeedReader) {
       let handlerApp = Cc["@mozilla.org/uriloader/local-handler-app;1"].
@@ -624,7 +630,7 @@ FeedHandlerInfo.prototype = {
   },
 
   get hasDefaultHandler() {
-//@line 694 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 704 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
     try {
       if (this._shellSvc.defaultFeedReader)
         return true;
@@ -632,7 +638,7 @@ FeedHandlerInfo.prototype = {
     catch(ex) {
       // no default reader or _shellSvc is null
     }
-//@line 702 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 712 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
 
     return false;
   },
@@ -1289,8 +1295,9 @@ var gApplicationsPane = {
 // XXXben - we need to compare this with the running instance executable
 //          just don't know how to do that via script...
 // XXXmano TBD: can probably add this to nsIShellService
+//@line 1374 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
    aExecutable.leafName != "firefox-bin";
-//@line 1367 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1377 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
   },
 
   /**
@@ -1411,7 +1418,7 @@ var gApplicationsPane = {
     }
 
     // Create a menu item for selecting a local application.
-//@line 1494 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1504 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
     {
       let menuItem = document.createElement("menuitem");
       menuItem.setAttribute("oncommand", "gApplicationsPane.chooseApp(event)");
@@ -1523,36 +1530,7 @@ var gApplicationsPane = {
    * Filter the list when the user enters a filter term into the filter field.
    */
   filter: function() {
-    if (this._filter.value == "") {
-      this.clearFilter();
-      return;
-    }
-
     this._rebuildView();
-
-    document.getElementById("clearFilter").disabled = false;
-  },
-
-  _filterTimeout: null,
-
-  onFilterInput: function() {
-    if (this._filterTimeout)
-      clearTimeout(this._filterTimeout);
-   
-    this._filterTimeout = setTimeout("gApplicationsPane.filter()", 500);
-  },
-
-  onFilterKeyPress: function(aEvent) {
-    if (aEvent.keyCode == KeyEvent.DOM_VK_ESCAPE)
-      this.clearFilter();
-  },
-  
-  clearFilter: function() {
-    this._filter.value = "";
-    this._rebuildView();
-
-    this._filter.focus();
-    document.getElementById("clearFilter").disabled = true;
   },
 
   focusFilterBox: function() {
@@ -1653,7 +1631,7 @@ var gApplicationsPane = {
 
     var handlerApp;
 
-//@line 1765 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1746 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
     var fp = Cc["@mozilla.org/filepicker;1"].createInstance(Ci.nsIFilePicker);
     var winTitle = this._prefsBundle.getString("fpTitleChooseApp");
     fp.init(window, winTitle, Ci.nsIFilePicker.modeOpen);
@@ -1672,7 +1650,7 @@ var gApplicationsPane = {
       let handlerInfo = this._handledTypes[this._list.selectedItem.type];
       handlerInfo.addPossibleApplicationHandler(handlerApp);
     }
-//@line 1784 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1765 "/builds/moz2_slave/linux_build/build/browser/components/preferences/applications.js"
 
     // Rebuild the actions menu whether the user picked an app or canceled.
     // If they picked an app, we want to add the app to the menu and select it.
