@@ -1,4 +1,4 @@
-//@line 39 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/safeMode.js"
+//@line 39 "/builds/moz2_slave/linux_build/build/browser/base/content/safeMode.js"
 
 function restartApp() {
   var appStartup = Components.classes["@mozilla.org/toolkit/app-startup;1"]
@@ -53,7 +53,15 @@ function disableAddons() {
   // Select the default theme
   var prefB = Components.classes["@mozilla.org/preferences-service;1"]
                         .getService(Components.interfaces.nsIPrefBranch);
-  prefB.clearUserPref("general.skins.selectedSkin");
+  if (prefB.prefHasUserValue("general.skins.selectedSkin"))
+    prefB.clearUserPref("general.skins.selectedSkin");
+
+  // Disable plugins
+  var phs = Components.classes["@mozilla.org/plugin/host;1"]
+                      .getService(Components.interfaces.nsIPluginHost);
+  var plugins = phs.getPluginTags({ });
+  for (i = 0; i < plugins.length; ++i)
+    plugins[i].disabled = true;
 }
 
 function restoreDefaultSearchEngines() {
