@@ -1,4 +1,4 @@
-//@line 39 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/sanitize.js"
+//@line 41 "/builds/moz2_slave/linux_build/build/browser/base/content/sanitize.js"
 
 function Sanitizer() {}
 Sanitizer.prototype = {
@@ -14,10 +14,11 @@ Sanitizer.prototype = {
     return this.items[aItemName].canClear;
   },
   
-  _prefDomain: "privacy.item.",
+  prefDomain: "",
+  
   getNameFromPreference: function (aPreferenceName)
   {
-    return aPreferenceName.substr(this._prefDomain.length);
+    return aPreferenceName.substr(this.prefDomain.length);
   },
   
   /**
@@ -30,10 +31,18 @@ Sanitizer.prototype = {
   {
     var psvc = Components.classes["@mozilla.org/preferences-service;1"]
                          .getService(Components.interfaces.nsIPrefService);
-    var branch = psvc.getBranch(this._prefDomain);
+    var branch = psvc.getBranch(this.prefDomain);
     var errors = null;
+
+    // Cache the range of times to clear
+    if (this.ignoreTimespan)
+      var range = null;  // If we ignore timespan, clear everything
+    else
+      range = this.range || Sanitizer.getClearRange();
+      
     for (var itemName in this.items) {
       var item = this.items[itemName];
+      item.range = range;
       if ("clear" in item && item.canClear && branch.getBoolPref(itemName)) {
         // Some of these clear() may raise exceptions (see bug #265028)
         // to sanitize as much as possible, we catch and store them, 
@@ -53,16 +62,26 @@ Sanitizer.prototype = {
     return errors;
   },
   
+  // Time span only makes sense in certain cases.  Consumers who want
+  // to only clear some private data can opt in by setting this to false,
+  // and can optionally specify a specific range.  If timespan is not ignored,
+  // and range is not set, sanitize() will use the value of the timespan
+  // pref to determine a range
+  ignoreTimespan : true,
+  range : null,
+  
   items: {
     cache: {
       clear: function ()
       {
-        const cc = Components.classes;
-        const ci = Components.interfaces;
-        var cacheService = cc["@mozilla.org/network/cache-service;1"]
-                             .getService(ci.nsICacheService);
+        const Cc = Components.classes;
+        const Ci = Components.interfaces;
+        var cacheService = Cc["@mozilla.org/network/cache-service;1"].
+                          getService(Ci.nsICacheService);
         try {
-          cacheService.evictEntries(ci.nsICache.STORE_ANYWHERE);
+          // Cache doesn't consult timespan, nor does it have the
+          // facility for timespan-based eviction.  Wipe it.
+          cacheService.evictEntries(Ci.nsICache.STORE_ANYWHERE);
         } catch(er) {}
       },
       
@@ -75,9 +94,33 @@ Sanitizer.prototype = {
     cookies: {
       clear: function ()
       {
+        const Ci = Components.interfaces;
         var cookieMgr = Components.classes["@mozilla.org/cookiemanager;1"]
-                                  .getService(Components.interfaces.nsICookieManager);
-        cookieMgr.removeAll();
+                                  .getService(Ci.nsICookieManager);
+        if (this.range) {
+          // Iterate through the cookies and delete any created after our cutoff.
+          var cookiesEnum = cookieMgr.enumerator;
+          while (cookiesEnum.hasMoreElements()) {
+            var cookie = cookiesEnum.getNext().QueryInterface(Ci.nsICookie2);
+            
+            if (cookie.creationTime > this.range[0])
+              // This cookie was created after our cutoff, clear it
+              cookieMgr.remove(cookie.host, cookie.name, cookie.path, false);
+          }
+        }
+        else {
+          // Remove everything
+          cookieMgr.removeAll();
+        }
+
+        // clear any network geolocation provider sessions
+        var psvc = Components.classes["@mozilla.org/preferences-service;1"]
+                             .getService(Components.interfaces.nsIPrefService);
+        try {
+            var branch = psvc.getBranch("geo.wifi.access_token.");
+            branch.deleteBranch("");
+        } catch (e) {}
+
       },
       
       get canClear()
@@ -94,6 +137,8 @@ Sanitizer.prototype = {
         var cacheService = Cc["@mozilla.org/network/cache-service;1"].
                            getService(Ci.nsICacheService);
         try {
+          // Offline app data is "timeless", and doesn't respect
+          // the setting of timespan, it always clears everything
           cacheService.evictEntries(Ci.nsICache.STORE_OFFLINE);
         } catch(er) {}
 
@@ -113,7 +158,10 @@ Sanitizer.prototype = {
       {
         var globalHistory = Components.classes["@mozilla.org/browser/global-history;2"]
                                       .getService(Components.interfaces.nsIBrowserHistory);
-        globalHistory.removeAllPages();
+        if (this.range)
+          globalHistory.QueryInterface(Components.interfaces.nsIBrowserHistory_MOZILLA_1_9_1_ADDITIONS).removeVisitsByTimeframe(this.range[0], this.range[1]);
+        else
+          globalHistory.removeAllPages();
         
         try {
           var os = Components.classes["@mozilla.org/observer-service;1"]
@@ -142,25 +190,40 @@ Sanitizer.prototype = {
     formdata: {
       clear: function ()
       {
-        //Clear undo history of all searchBars
-        var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService();
-        var windowManagerInterface = windowManager.QueryInterface(Components.interfaces.nsIWindowMediator);
-        var windows = windowManagerInterface.getEnumerator("navigator:browser");
+        // Clear undo history of all searchBars
+        var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1']
+                                      .getService(Components.interfaces.nsIWindowMediator);
+        var windows = windowManager.getEnumerator("navigator:browser");
         while (windows.hasMoreElements()) {
           var searchBar = windows.getNext().document.getElementById("searchbar");
-          if (searchBar) {
-            searchBar.value = "";
-            searchBar.textbox.editor.transactionManager.clear();
-          }
+          if (searchBar)
+            searchBar.textbox.reset();
         }
 
         var formHistory = Components.classes["@mozilla.org/satchel/form-history;1"]
                                     .getService(Components.interfaces.nsIFormHistory2);
-        formHistory.removeAllEntries();
+        if (this.range)
+          formHistory.removeEntriesByTimeframe(this.range[0], this.range[1]);
+        else
+          formHistory.removeAllEntries();
       },
-      
+
       get canClear()
       {
+        var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1']
+                                      .getService(Components.interfaces.nsIWindowMediator);
+        var windows = windowManager.getEnumerator("navigator:browser");
+        while (windows.hasMoreElements()) {
+          var searchBar = windows.getNext().document.getElementById("searchbar");
+          if (searchBar) {
+            var transactionMgr = searchBar.textbox.editor.transactionManager;
+            if (searchBar.value ||
+                transactionMgr.numberOfUndoItems ||
+                transactionMgr.numberOfRedoItems)
+              return true;
+          }
+        }
+
         var formHistory = Components.classes["@mozilla.org/satchel/form-history;1"]
                                     .getService(Components.interfaces.nsIFormHistory2);
         return formHistory.hasEntries;
@@ -172,7 +235,35 @@ Sanitizer.prototype = {
       {
         var dlMgr = Components.classes["@mozilla.org/download-manager;1"]
                               .getService(Components.interfaces.nsIDownloadManager);
-        dlMgr.cleanUp();
+
+        var dlIDsToRemove = [];
+        if (this.range) {
+          // First, remove the completed/cancelled downloads
+          dlMgr.removeDownloadsByTimeframe(this.range[0], this.range[1]);
+          
+          // Queue up any active downloads that started in the time span as well
+          var dlsEnum = dlMgr.activeDownloads;
+          while(dlsEnum.hasMoreElements()) {
+            var dl = dlsEnum.next();
+            if(dl.startTime >= this.range[0])
+              dlIDsToRemove.push(dl.id);
+          }
+        }
+        else {
+          // Clear all completed/cancelled downloads
+          dlMgr.cleanUp();
+          
+          // Queue up all active ones as well
+          var dlsEnum = dlMgr.activeDownloads;
+          while(dlsEnum.hasMoreElements()) {
+            dlIDsToRemove.push(dlsEnum.next().id);
+          }
+        }
+        
+        // Remove any queued up active downloads
+        dlIDsToRemove.forEach(function(id) {
+          dlMgr.removeDownload(id);
+        });
       },
 
       get canClear()
@@ -188,6 +279,7 @@ Sanitizer.prototype = {
       {
         var pwmgr = Components.classes["@mozilla.org/login-manager;1"]
                               .getService(Components.interfaces.nsILoginManager);
+        // Passwords are timeless, and don't respect the timeSpan setting
         pwmgr.removeAllLogins();
       },
       
@@ -214,6 +306,24 @@ Sanitizer.prototype = {
         authMgr.clearAll();
       },
       
+      get canClear()
+      {
+        return true;
+      }
+    },
+    
+    siteSettings: {
+      clear: function ()
+      {
+        var pm = Components.classes["@mozilla.org/permissionmanager;1"]
+                          .getService(Components.interfaces.nsIPermissionManager);
+        pm.removeAll();
+        
+        var cps = Components.classes["@mozilla.org/content-pref/service;1"]
+                           .getService(Components.interfaces.nsIContentPrefService);
+        cps.removeGroupedPrefs();
+      },
+      
       get canClear()
       {
         return true;
@@ -226,10 +336,52 @@ Sanitizer.prototype = {
 
 // "Static" members
 Sanitizer.prefDomain          = "privacy.sanitize.";
-Sanitizer.prefPrompt          = "promptOnSanitize";
 Sanitizer.prefShutdown        = "sanitizeOnShutdown";
 Sanitizer.prefDidShutdown     = "didShutdownSanitize";
 
+// Time span constants corresponding to values of the privacy.sanitize.timeSpan
+// pref.  Used to determine how much history to clear, for various items
+Sanitizer.TIMESPAN_EVERYTHING = 0;
+Sanitizer.TIMESPAN_HOUR       = 1;
+Sanitizer.TIMESPAN_2HOURS     = 2;
+Sanitizer.TIMESPAN_4HOURS     = 3;
+Sanitizer.TIMESPAN_TODAY      = 4;
+
+// Return a 2 element array representing the start and end times,
+// in the uSec-since-epoch format that PRTime likes.  If we should
+// clear everything, return null.  Use ts if it is defined; otherwise
+// use the timeSpan pref.
+Sanitizer.getClearRange = function (ts) {
+  if (ts === undefined)
+    ts = Sanitizer.prefs.getIntPref("timeSpan");
+  if (ts === Sanitizer.TIMESPAN_EVERYTHING)
+    return null;
+  
+  // PRTime is microseconds while JS time is milliseconds
+  var endDate = Date.now() * 1000;
+  switch (ts) {
+    case Sanitizer.TIMESPAN_HOUR :
+      var startDate = endDate - 3600000000; // 1*60*60*1000000
+      break;
+    case Sanitizer.TIMESPAN_2HOURS :
+      startDate = endDate - 7200000000; // 2*60*60*1000000
+      break;
+    case Sanitizer.TIMESPAN_4HOURS :
+      startDate = endDate - 14400000000; // 4*60*60*1000000
+      break;
+    case Sanitizer.TIMESPAN_TODAY :
+      var d = new Date();  // Start with today
+      d.setHours(0);      // zero us back to midnight...
+      d.setMinutes(0);
+      d.setSeconds(0);
+      startDate = d.valueOf() * 1000; // convert to epoch usec
+      break;
+    default:
+      throw "Invalid time span for clear private data: " + ts;
+  }
+  return [startDate, endDate];
+};
+
 Sanitizer._prefs = null;
 Sanitizer.__defineGetter__("prefs", function() 
 {
@@ -244,12 +396,12 @@ Sanitizer.showUI = function(aParentWindow)
 {
   var ww = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                      .getService(Components.interfaces.nsIWindowWatcher);
-//@line 287 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/sanitize.js"
+//@line 441 "/builds/moz2_slave/linux_build/build/browser/base/content/sanitize.js"
   ww.openWindow(aParentWindow,
-//@line 289 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/base/content/sanitize.js"
+//@line 443 "/builds/moz2_slave/linux_build/build/browser/base/content/sanitize.js"
                 "chrome://browser/content/sanitize.xul",
                 "Sanitize",
-                "chrome,titlebar,centerscreen,modal",
+                "chrome,titlebar,dialog,centerscreen,modal",
                 null);
 };
 
@@ -257,17 +409,12 @@ Sanitizer.showUI = function(aParentWindow)
  * Deletes privacy sensitive data in a batch, optionally showing the 
  * sanitize UI, according to user preferences
  *
- * @returns  null if everything's fine (no error or displayed UI,  which
- *           should handle errors);  
- *           an object in the form { itemName: error, ... } on (partial) failure
+ * @returns  null (displayed UI, which should handle errors)
  */
 Sanitizer.sanitize = function(aParentWindow) 
 {
-  if (Sanitizer.prefs.getBoolPref(Sanitizer.prefPrompt)) {
-    Sanitizer.showUI(aParentWindow);
-    return null;
-  }
-  return new Sanitizer().sanitize();
+  Sanitizer.showUI(aParentWindow);
+  return null;
 };
 
 Sanitizer.onStartup = function() 
@@ -289,7 +436,9 @@ Sanitizer._checkAndSanitize = function()
   if (prefs.getBoolPref(Sanitizer.prefShutdown) && 
       !prefs.prefHasUserValue(Sanitizer.prefDidShutdown)) {
     // this is a shutdown or a startup after an unclean exit
-    Sanitizer.sanitize(null) || // sanitize() returns null on full success
+    var s = new Sanitizer();
+    s.prefDomain = "privacy.clearOnShutdown.";
+    s.sanitize() || // sanitize() returns null on full success
       prefs.setBoolPref(Sanitizer.prefDidShutdown, true);
   }
 };
