@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/toolkit/components/nsDefaultCLH.js"
+//@line 38 "/builds/moz2_slave/linux_build/build/toolkit/components/nsDefaultCLH.js"
 
 const nsISupports              = Components.interfaces.nsISupports;
 
@@ -78,6 +78,10 @@ var nsDefaultCLH = {
       dump(out + "\n");
       Components.utils.reportError(out);
     }
+    
+    if (cmdLine.handleFlag("silent", false)) {
+      cmdLine.preventDefault = true;
+    }
 
     if (cmdLine.preventDefault)
       return;
